@@ -251,11 +251,31 @@ class Client(BaseClient):
         return self.do('GET', '/api/1/orders/{id}', req=req, auth=True)
 
     def get_order_book(self, pair):
+        """Makes a call to GET /api/1/orderbook_top.
+
+        Returns a list of the top 100 bids and asks in the order book.
+        Ask orders are sorted by price ascending.
+        Bid orders are sorted by price descending.
+        Orders of the same price are aggregated.
+
+        :param pair: Currency pair
+        :type pair: str
+        """
+        req = {
+            'pair': pair,
+        }
+        return self.do('GET', '/api/1/orderbook_top', req=req, auth=False)
+
+    def get_order_book_full(self, pair):
         """Makes a call to GET /api/1/orderbook.
 
-        Returns a list of bids and asks in the order book. Ask orders are sorted by
-        price ascending. Bid orders are sorted by price descending. Note that
-        multiple orders at the same price are not necessarily conflated.
+        Returns a list of all bids and asks in the order book.
+        Ask orders are sorted by price ascending.
+        Bid orders are sorted by price descending.
+        Multiple orders at the same price are not aggregated.
+
+        Warning: This may return a large amount of data. Generally you should rather
+        use GetOrderBook or the Streaming API.
 
         :param pair: Currency pair
         :type pair: str
@@ -409,11 +429,12 @@ class Client(BaseClient):
         }
         return self.do('GET', '/api/1/accounts/{id}/transactions', req=req, auth=True)
 
-    def list_user_trades(self, pair, limit=None, since=None):
+    def list_user_trades(self, pair, after_seq=None, before=None, before_seq=None, limit=None, since=None, sort_desc=None):
         """Makes a call to GET /api/1/listtrades.
 
         Returns a list of your recent trades for a given pair, sorted by oldest
-        first.
+        first. If <code>before</code> is specified, then the trades are returned
+        sorted by most-recent first.
 
         <code>type</code> in the response indicates the type of order that you placed
         in order to participate in the trade. Possible types: <code>BID</code>,
@@ -428,15 +449,30 @@ class Client(BaseClient):
 
         :param pair: Filter to trades of this currency pair.
         :type pair: str
+        :param after_seq: Filter to trades from (including) this sequence number.
+                          Default behaviour is not to include this filter.
+        :type after_seq: int
+        :param before: Filter to trades before this timestamp.
+        :type before: int
+        :param before_seq: Filter to trades before (excluding) this sequence number.
+                           Default behaviour is not to include this filter.
+        :type before_seq: int
         :param limit: Limit to this number of trades (default 100).
         :type limit: int
         :param since: Filter to trades on or after this timestamp.
         :type since: int
+        :param sort_desc: If set to true, sorts trades in descending order, otherwise ascending
+                          order will be assumed.
+        :type sort_desc: bool
         """
         req = {
             'pair': pair,
+            'after_seq': after_seq,
+            'before': before,
+            'before_seq': before_seq,
             'limit': limit,
             'since': since,
+            'sort_desc': sort_desc,
         }
         return self.do('GET', '/api/1/listtrades', req=req, auth=True)
 
@@ -450,7 +486,7 @@ class Client(BaseClient):
         """
         return self.do('GET', '/api/1/withdrawals', req=None, auth=True)
 
-    def post_limit_order(self, pair, price, type, volume, base_account_id=None, counter_account_id=None):
+    def post_limit_order(self, pair, price, type, volume, base_account_id=None, counter_account_id=None, post_only=None):
         """Makes a call to POST /api/1/postorder.
 
         Create a new trade order.
@@ -479,6 +515,12 @@ class Client(BaseClient):
         :type base_account_id: str
         :param counter_account_id: The counter currency account to use in the trade.
         :type counter_account_id: str
+        :param post_only: Post-only orders will be cancelled if they would otherwise have traded
+                          immediately. For example, if there's a bid at ZAR 100,000 and you place
+                          a post-only ask at ZAR 100,000, your order will be cancelled instead of
+                          trading. If the best bid is ZAR 100,000 and you place a post-only ask at
+                          ZAR 101,000, your order won't trade but will go into the order book.
+        :type post_only: bool
         """
         req = {
             'pair': pair,
@@ -487,6 +529,7 @@ class Client(BaseClient):
             'volume': volume,
             'base_account_id': base_account_id,
             'counter_account_id': counter_account_id,
+            'post_only': post_only,
         }
         return self.do('POST', '/api/1/postorder', req=req, auth=True)
 
@@ -543,7 +586,7 @@ class Client(BaseClient):
         If the email address is not associated with an existing Luno account, an
         invitation to create an account and claim the funds will be sent.
 
-        Warning! Digital currency transactions are irreversible. Please ensure your
+        Warning! Cryptocurrency transactions are irreversible. Please ensure your
         program has been thoroughly tested before using this call.
 
         Permissions required: <code>Perm_W_Send</code>
